@@ -1,9 +1,8 @@
 import argparse
 import functools
+from typing import Any
 
-import gcalcli
-from gcalcli.printer import valid_color_name, Printer
-
+from .printer import Printer, valid_color_name
 
 printer = Printer()
 
@@ -70,10 +69,10 @@ BASE_OPTS = {'program': {'type': str,
                         'action': DeprecatedStoreTrue}}
 
 
-OPTIONS = {
+OPTIONS: dict[str, dict[str, Any]] = {
     'program': {
-        "--client_id": {'default': gcalcli.__API_CLIENT_ID__},
-        "--client_secret": {'default': gcalcli.__API_CLIENT_SECRET__},
+        "--client_id": {'default': None},
+        "--client_secret": {'default': None},
         "--configFolder": {'default': None},
         "--defaultCalendar": {'default': [], 'action': DeprecatedAppend}
     },
