@@ -1,8 +1,12 @@
 import re
+from typing import Optional
 
-from gcalcli.exceptions import ValidationError
-from gcalcli.utils import (REMINDER_REGEX, get_time_from_str,
-                           get_timedelta_from_str)
+from .exceptions import ValidationError
+from .utils import (
+    get_time_from_str,
+    get_timedelta_from_str,
+    REMINDER_REGEX,
+)
 
 # TODO: in the future, pull these from the API
 # https://developers.google.com/calendar/v3/reference/colors
@@ -10,16 +14,25 @@ VALID_OVERRIDE_COLORS = ['lavender', 'sage', 'grape', 'flamingo',
                          'banana', 'tangerine', 'peacock', 'graphite',
                          'blueberry', 'basil', 'tomato']
 
+DATE_INPUT_DESCRIPTION = '\
+a date (e.g. 2019-12-31, tomorrow 10am, 2nd Jan, Jan 4th, etc) or valid time \
+if today'
+
 
 def get_override_color_id(color):
     return str(VALID_OVERRIDE_COLORS.index(color) + 1)
 
 
-def get_input(printer, prompt, validator_func):
+def get_input(printer, prompt, validator_func, help: Optional[str] = None):
     printer.msg(prompt, 'magenta')
     while True:
         try:
-            output = validate_input(validator_func)
+            answer = input()
+            if answer.strip() == '?' and help:
+                printer.msg(f'{help}\n')
+                printer.msg(prompt, 'magenta')
+                continue
+            output = validator_func(answer)
             return output
         except ValidationError as e:
             printer.msg(e.message, 'red')
@@ -69,8 +82,7 @@ def parsable_date_validator(input_str):
         return input_str
     except ValueError:
         raise ValidationError(
-            'Expected format: a date (e.g. 2019-01-01, tomorrow 10am, '
-            '2nd Jan, Jan 4th, etc) or valid time if today. '
+            f'Expected format: {DATE_INPUT_DESCRIPTION}. '
             '(Ctrl-C to exit)\n'
         )
 
@@ -125,14 +137,6 @@ def reminder_validator(input_str):
                               '<popup|email|sms>. (Ctrl-C to exit)\n')
 
 
-def validate_input(validator_func):
-    """
-    Wrapper around Validator funcs.
-    """
-    inp_str = input()
-    return validator_func(inp_str)
-
-
 STR_NOT_EMPTY = non_blank_str_validator
 STR_ALLOW_EMPTY = str_allow_empty_validator
 STR_TO_INT = str_to_int_validator
