@@ -1,8 +1,10 @@
-from gcalcli import argparsers
 from collections import namedtuple
 import shlex
+
 import pytest
 
+from gcalcli import argparsers
+
 
 def test_get_argparser():
     """Just asserts no errors have been introduced"""
@@ -98,4 +100,4 @@ def test_handle_unparsed():
     argv = shlex.split('delete --calendar=test "search text"')
     parsed, unparsed = parser.parse_known_args(argv)
     parsed = argparsers.handle_unparsed(unparsed, parsed)
-    assert parsed.calendar == ['test']
+    assert parsed.calendars == ['test']
