@@ -1,13 +1,9 @@
 import pytest
 
-from gcalcli.validators import validate_input, ValidationError
-from gcalcli.validators import (STR_NOT_EMPTY,
-                                PARSABLE_DATE,
-                                PARSABLE_DURATION,
-                                STR_TO_INT,
-                                STR_ALLOW_EMPTY,
-                                REMINDER,
-                                VALID_COLORS)
+from gcalcli.validators import (PARSABLE_DATE, PARSABLE_DURATION, REMINDER,
+                                STR_ALLOW_EMPTY, STR_NOT_EMPTY, STR_TO_INT,
+                                VALID_COLORS, ValidationError)
+
 # Tests required:
 #
 # * Title: any string, not blank
@@ -23,25 +19,25 @@ def test_any_string_not_blank_validator(monkeypatch):
     # Empty string raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "")
     with pytest.raises(ValidationError):
-        validate_input(STR_NOT_EMPTY) == ValidationError(
+        STR_NOT_EMPTY(input()) == ValidationError(
             "Input here cannot be empty")
 
     # None raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: None)
     with pytest.raises(ValidationError):
-        validate_input(STR_NOT_EMPTY) == ValidationError(
+        STR_NOT_EMPTY(input()) == ValidationError(
             "Input here cannot be empty")
 
     # Valid string passes
     monkeypatch.setattr("builtins.input", lambda: "Valid Text")
-    assert validate_input(STR_NOT_EMPTY) == "Valid Text"
+    assert STR_NOT_EMPTY(input()) == "Valid Text"
 
 
 def test_any_string_parsable_by_dateutil(monkeypatch):
     # non-date raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "NON-DATE STR")
     with pytest.raises(ValidationError):
-        validate_input(PARSABLE_DATE) == ValidationError(
+        PARSABLE_DATE(input()) == ValidationError(
             "Expected format: a date (e.g. 2019-01-01, tomorrow 10am, "
             "2nd Jan, Jan 4th, etc) or valid time if today. "
             "(Ctrl-C to exit)\n"
@@ -49,14 +45,14 @@ def test_any_string_parsable_by_dateutil(monkeypatch):
 
     # date string passes
     monkeypatch.setattr("builtins.input", lambda: "2nd January")
-    validate_input(PARSABLE_DATE) == "2nd January"
+    PARSABLE_DATE(input()) == "2nd January"
 
 
 def test_any_string_parsable_by_parsedatetime(monkeypatch):
     # non-date raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "NON-DATE STR")
     with pytest.raises(ValidationError) as ve:
-        validate_input(PARSABLE_DURATION)
+        PARSABLE_DURATION(input())
     assert ve.value.message == (
             'Expected format: a duration (e.g. 1m, 1s, 1h3m)'
             '(Ctrl-C to exit)\n'
@@ -64,71 +60,71 @@ def test_any_string_parsable_by_parsedatetime(monkeypatch):
 
     # duration string passes
     monkeypatch.setattr("builtins.input", lambda: "1m")
-    assert validate_input(PARSABLE_DURATION) == "1m"
+    assert PARSABLE_DURATION(input()) == "1m"
 
     # duration string passes
     monkeypatch.setattr("builtins.input", lambda: "1h2m")
-    assert validate_input(PARSABLE_DURATION) == "1h2m"
+    assert PARSABLE_DURATION(input()) == "1h2m"
 
 
 def test_string_can_be_cast_to_int(monkeypatch):
     # non int-castable string raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "X")
     with pytest.raises(ValidationError):
-        validate_input(STR_TO_INT) == ValidationError(
+        STR_TO_INT(input()) == ValidationError(
             "Input here must be a number")
 
     # int string passes
     monkeypatch.setattr("builtins.input", lambda: "10")
-    validate_input(STR_TO_INT) == "10"
+    STR_TO_INT(input()) == "10"
 
 
 def test_for_valid_colour_name(monkeypatch):
     # non valid colour raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "purple")
     with pytest.raises(ValidationError):
-        validate_input(VALID_COLORS) == ValidationError(
+        VALID_COLORS(input()) == ValidationError(
             "purple is not a valid color value to use here. Please "
             "use one of basil, peacock, grape, lavender, blueberry,"
             "tomato, safe, flamingo or banana."
         )
     # valid colour passes
     monkeypatch.setattr("builtins.input", lambda: "grape")
-    validate_input(VALID_COLORS) == "grape"
+    VALID_COLORS(input()) == "grape"
 
     # empty str passes
     monkeypatch.setattr("builtins.input", lambda: "")
-    validate_input(VALID_COLORS) == ""
+    VALID_COLORS(input()) == ""
 
 
 def test_any_string_and_blank(monkeypatch):
     # string passes
     monkeypatch.setattr("builtins.input", lambda: "TEST")
-    validate_input(STR_ALLOW_EMPTY) == "TEST"
+    STR_ALLOW_EMPTY(input()) == "TEST"
 
 
 def test_reminder(monkeypatch):
     # valid reminders pass
     monkeypatch.setattr("builtins.input", lambda: "10m email")
-    validate_input(REMINDER) == "10m email"
+    REMINDER(input()) == "10m email"
 
     monkeypatch.setattr("builtins.input", lambda: "10 popup")
-    validate_input(REMINDER) == "10m email"
+    REMINDER(input()) == "10m email"
 
     monkeypatch.setattr("builtins.input", lambda: "10m sms")
-    validate_input(REMINDER) == "10m email"
+    REMINDER(input()) == "10m email"
 
     monkeypatch.setattr("builtins.input", lambda: "12323")
-    validate_input(REMINDER) == "10m email"
+    REMINDER(input()) == "10m email"
 
     # invalid reminder raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "meaningless")
     with pytest.raises(ValidationError):
-        validate_input(REMINDER) == ValidationError(
+        REMINDER(input()) == ValidationError(
             "Format: <number><w|d|h|m> <popup|email|sms>\n")
 
     # invalid reminder raises ValidationError
     monkeypatch.setattr("builtins.input", lambda: "")
     with pytest.raises(ValidationError):
-        validate_input(REMINDER) == ValidationError(
+        REMINDER(input()) == ValidationError(
             "Format: <number><w|d|h|m> <popup|email|sms>\n")
