@@ -1,7 +1,9 @@
-import gcalcli.utils as utils
 from datetime import datetime, timedelta
-from dateutil.tz import UTC
+
 import pytest
+from dateutil.tz import UTC, tzutc
+
+from gcalcli import utils
 
 
 def test_get_time_from_str():
@@ -70,3 +72,12 @@ def test_days_since_epoch():
 def test_set_locale():
     with pytest.raises(ValueError):
         utils.set_locale('not_a_real_locale')
+
+
+def test_localize_datetime(PatchedGCalI):
+    dt = utils.localize_datetime(datetime.now())
+    assert dt.tzinfo is not None
+
+    dt = datetime.now(tzutc())
+    dt = utils.localize_datetime(dt)
+    assert dt.tzinfo is not None
